{% load static %}

{{ table_meta|json_script:"__cascade-filter__table-meta" }}

<textarea id="__cascade-filter__field" name="{{ widget.name }}" hidden>
{% if widget.value %}{{ widget.value }}{% endif %}</textarea>
<div id="__cascade-filter__editor" style="overflow: auto;"></div>

<script src="{% static 'cascade_filter/cascade-filter.umd.js' %}"></script>
