input.svelte-18leb9j{width:140px;height:25px;padding:2px!important}.single-filter.svelte-1ffugca{max-width:600px;border:solid 1px rgba(124,124,124,.3);border-radius:10px;display:grid;grid-template-columns:1fr 30px;gap:5px}.single-filter__main-content.svelte-1ffugca{padding:5px;display:grid;grid-template-columns:min-content max-content max-content 1fr;gap:5px}.btn-delete.svelte-1ffugca{border:none;border-radius:0 10px 10px 0;background-color:#ff0000b3;color:#fff;font-size:15px}.btn-delete.svelte-1ffugca:hover{cursor:pointer;color:#000}.disabled.svelte-1ffugca{background-color:#0000001a}.multi-filter.svelte-w27rta{display:flex;margin-bottom:10px;padding:5px}.multi-filter__head.svelte-w27rta{align-self:center;margin-right:10px;min-width:70px;display:flex;flex-direction:row;justify-content:space-between}.multi-filter__head.svelte-w27rta>div:where(.svelte-w27rta){margin-left:5px}.btn-delete.svelte-w27rta{background-color:#ff0000b3;border:none;color:#fff;border-radius:5px;margin-left:5px;font-size:15px;padding-inline:.1em}.btn-delete.svelte-w27rta:hover{cursor:pointer;color:#000}.multi-filter__body.svelte-w27rta{border-left:1px solid #79aec8;border-radius:10px;padding:10px}.disabled.svelte-w27rta{background-color:#0000001a;border-radius:10px}span.svelte-rveqii{color:red}dialog.svelte-1cjh3t0{border:none}dialog.svelte-1cjh3t0::backdrop{background-color:#0006}input.svelte-1fgf3s5{width:140px;height:25px;padding:2px!important;margin-top:1em}label.svelte-prgwgy,label.svelte-1d481sh{width:100%}input.svelte-1d481sh{width:20em}label.svelte-prgwgy{width:100%}.dialog__header.svelte-ux1d7j{padding:2px 16px;background-color:var(--primary, #79aec8);color:#fff}.dialog__body.svelte-ux1d7j{padding:10px;background-color:var(--body-bg, white)}.btn-close.svelte-ux1d7j{color:#fff;float:right;font-size:28px;font-weight:700;background:transparent;border:none}.btn-close.svelte-ux1d7j:hover{cursor:pointer;color:#000}.btn-close.svelte-ux1d7j:focus{outline:none}hr.svelte-ux1d7j{margin-block:1em}
